==> forms-v5.2.1.tar.gz: forms/l10n/lt_LT.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Anketos",
    "{user} has shared the form {formTitle} with you" : "{user} pradėjo bendrinti su jumis anketą, pavadinimu {formTitle}",
    "Anonymous user" : "Anoniminis naudotojas",
    "A form has been <strong>shared</strong> with you" : "Su jumis pradėta <strong>bendrinti</strong> anketa",
    "Someone <strong>answered</strong> a form" : "Kažkas <strong>užpildė</strong> anketą",
    "No" : "Ne",
    "Yes" : "Taip",
    "Question" : "Klausimas",
    "Answer" : "Atsakymas",
    "Copy" : "Kopija",
    "Anonymous response" : "Anoniminis atsakymas",
    "Shared by %s" : "Bendrina %s",
    "responses" : "atsakymai",
    "User ID" : "Naudotojo ID",
    "Timestamp" : "Laiko žyma",
    "An error occurred while loading the forms list" : "Įkeliant anketų sąrašą, įvyko klaida",
    "Form not found" : "Anketa nerasta",
    "Unable to create a new form" : "Nepavyko sukurti naujos anketos",
    "Unable to copy form" : "Nepavyko nukopijuoti anketos",
    "New form" : "Nauja anketa",
    "Your forms" : "Jūsų anketos",
    "Shared with you" : "Bendrinama su jumis",
    "Archived forms" : "Archyvuotos anketos",
    "Loading forms …" : "Įkeliamos anketos…",
    "No forms created yet" : "Kol kas nėra sukurtų anketų",
    "Create a form" : "Sukurti anketą",
    "Select a form or create a new one" : "Pasirinkite anketą arba sukurkite naują",
    "Please select a form" : "Pasirinkite anketą",
    "Create new form" : "Sukurti naują anketą",
    "This form does not exist" : "Šios anketos nėra",
    "Form expired" : "Anketa nebegalioja",
    "This form has expired and is no longer taking answers" : "Ši anketa nebegalioja ir daugiau nebepriima atsakymų",
    "Error while saving configuration" : "Klaida įrašant konfigūraciją",
    "Error while reloading config" : "Klaida iš naujo įkeliant konfigūraciją",
    "Form creation" : "Anketos kūrimas",
    "Select groups" : "Pasirinkti grupes",
    "Form sharing" : "Anketos bendrinimas",
    "Allow sharing by link" : "Leisti bendrinti pagal nuorodą",
    "Delete form" : "Ištrinti anketą",
    "Expired {relativeDate}" : "Nustojo galioti {relativeDate}",
    "Expires {relativeDate}" : "Galioja iki {relativeDate}",
    "Error while deleting {title}" : "Klaida ištrinant {title}",
    "Edit form" : "Taisyti anketą",
    "Share form" : "Bendrinti anketą",
    "Results" : "Rezultatai",
    "Copy form" : "Kopijuoti anketą",
    "Unarchive form" : "Išarchyvuoti anketą",
    "Archive form" : "Archyvuoti anketą",
    "Are you sure you want to delete {title}?" : "Ar tikrai norite ištrinti {title}?",
    "Cancel" : "Atsisakyti",
    "Options" : "Parinktys",
    "Answer number {index}" : "Atsakymas nr. {index}",
    "Error while saving the answer" : "Klaida įrašant atsakymą",
    "Delete answer" : "Ištrinti atsakymą",
    "This question needs a title!" : "Šiam klausimui reikalinga antraštė!",
    "Question number {index}" : "Klausimas nr. {index}",
    "Move question up" : "Pakelti klausimą",
    "Move question down" : "Nuleisti klausimą",
    "Title of question number {index}" : "Klausimo nr. {index} antraštė",
    "Required" : "Privalomas",
    "Technical name of the question" : "Techninis klausimo pavadinimas",
    "Technical name" : "Techninis pavadinimas",
    "Copy question" : "Kopijuoti klausimą",
    "Delete question" : "Ištrinti klausimą",
    "Allowed file types: {fileTypes}." : "Leidžiami failo tipai: {fileTypes}.",
    "All file types are allowed." : "Leidžiami visi failo tipai.",
    "Maximum file size" : "Didžiausias failo dydis",
    "Delete" : "Ištrinti",
    "Uploading …" : "Įkeliama…",
    "Add new file as answer" : "Pridėti naują failą kaip atsakymą",
    "A long answer for the question “{text}”" : "Ilgas atsakymas į klausimą „{text}“",
    "Other" : "Kita",
    "A short answer for the question “{text}”" : "Trumpas atsakymas į klausimą „{text}“",
    "No response" : "Nėra atsakymo",
    "Delete this response" : "Ištrinti šį atsakymą",
    "Expired on {date}" : "Nustojo galioti {date}",
    "Expires on {date}" : "Galioja iki {date}",
    "never" : "niekada",
    "Allow multiple responses per person" : "Leisti kiekvienam žmogui atsakinėti po keletą kartų",
    "Set expiration date" : "Nustatyti galiojimo pabaigos datą",
    "Search for user, group or team …" : "Ieškoti naudotojo, grupės ar komandos…",
    "Group" : "Grupė",
    "Team" : "Komanda",
    "Permissions" : "Leidimai",
    "There was an error while adding the share" : "Pridedant viešinį įvyko klaida",
    "There was an error while adding the link" : "Pridedant nuorodą įvyko klaida",
    "There was an error while removing the share" : "Šalinant viešinį įvyko klaida",
    "Share link" : "Viešinio nuoroda",
    "Add link" : "Pridėti nuorodą",
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Show QR code" : "Rodyti QR kodą",
    "Copy embedding code" : "Kopijuoti įterpimo kodą",
    "Remove link" : "Šalinti nuorodą",
    "Internal link" : "Vidinė nuoroda",
    "Show to all accounts on sidebar" : "Rodyti visoms paskyroms šoninėje juostoje",
    "Search for a user" : "Ieškoti naudotojo",
    "View form" : "Rodyti anketą",
    "View" : "Rodyti",
    "Edit" : "Taisyti",
    "Show results" : "Rodyti rezultatus",
    "Share" : "Bendrinti",
    "Responses are anonymous." : "Atsakymai yra anoniminiai.",
    "An asterisk (*) indicates mandatory questions." : "Privalomi klausimai yra pažymėti žvaigždute (*).",
    "Expired {relativeDate}." : "Nustojo galioti {relativeDate}.",
    "Expires {relativeDate}." : "Galioja iki {relativeDate}.",
    "There was an error while adding the new question" : "Pridedant naują klausimą, įvyko klaida",
    "There was an error while removing the question" : "Šalinant klausimą, įvyko klaida",
    "Error while saving form" : "Klaida įrašant anketą",
    "Create form" : "Sukurti anketą",
    "Loading {title} …" : "Įkeliama {title}…",
    "Form is archived" : "Anketa yra archyvuota",
    "Form title" : "Anketos pavadinimas",
    "Description" : "Aprašas",
    "Add a question" : "Pridėti klausimą",
    "Summary" : "Santrauka",
    "Responses" : "Atsakymai",
    "There was an error while loading the results" : "Įkeliant rezultatus, įvyko klaida",
    "Export successful to {file}" : "Eksportavimas į {file} sėkmingas",
    "There was an error while removing this response" : "Šalinant šį atsakymą, įvyko klaida",
    "There was an error while removing responses" : "Šalinant atsakymus, įvyko klaida",
    "Create XLSX" : "Sukurti XLSX",
    "Create CSV" : "Sukurti CSV",
    "Create ODS" : "Sukurti ODS",
    "{amount} responses" : "Atsakymų: {amount}",
    "Download" : "Atsisiųsti",
    "Delete all responses" : "Ištrinti visus atsakymus",
    "Search" : "Paieška",
    "Loading responses …" : "Įkeliami atsakymai…",
    "No results found" : "Nerasta jokių rezultatų",
    "No responses yet" : "Kol kas atsakymų nėra",
    "Results of submitted forms will show up here" : "Čia bus rodomi pateiktų anketų rezultatai",
    "Form settings" : "Anketos nustatymai",
    "Sharing" : "Bendrinimas",
    "Settings" : "Nustatymai",
    "Abort" : "Nutraukti",
    "Submit" : "Pateikti",
    "Clear" : "Išvalyti",
    "There was an error submitting the form" : "Pateikiant anketą, įvyko klaida",
    "Submit form" : "Pateikti anketą",
    "Submitting form …" : "Anketa pateikiama…",
    "Thank you for completing the form!" : "Dėkojame, kad užpildėte anketą!",
    "Error while saving question" : "Klaida įrašant klausimą",
    "Form link copied" : "Anketos nuoroda nukopijuota",
    "Cannot copy, please copy the link manually" : "Nepavyksta nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
    "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
    "No elements found." : "Nerasta jokių elementų.",
    "Checkboxes" : "Žymimieji langeliai",
    "Checkbox question title" : "Žymimųjų langelių klausimo antraštė",
    "Enter your answer" : "Įveskite atsakymą",
    "This question needs a title and at least one answer!" : "Šiam klausimui reikia antraštės ir bent vieno atsakymo!",
    "Dropdown" : "Išskleidžiamasis langelis",
    "Dropdown question title" : "Išskleidžiamojo langelio klausimo antraštė",
    "People can pick one option" : "Žmonės galės pasirinkti vieną variantą",
    "Pick an option" : "Pasirinkite variantą",
    "File" : "Failas",
    "Short answer" : "Trumpas atsakymas",
    "Short answer question title" : "Trumpo atsakymo klausimo antraštė",
    "People can enter a short answer" : "Žmonės galės įvesti trumpą atsakymą",
    "Long text" : "Ilgas atsakymas",
    "Long text question title" : "Ilgo teksto klausimo antraštė",
    "People can enter a long text" : "Žmonės galės įvesti ilgą atsakymą",
    "Date" : "Data",
    "Date question title" : "Datos klausimo antraštė",
    "People can pick a date" : "Žmonės galės pasirinkti datą",
    "Pick a date" : "Pasirinkite datą",
    "Datetime" : "Data ir laikas",
    "Datetime question title" : "Datos ir laiko klausimo antraštė",
    "People can pick a date and time" : "Žmonės galės pasirinkti datą ir laiką",
    "Pick a date and time" : "Pasirinkite datą ir laiką",
    "Time" : "Laikas",
    "Pick a time" : "Pasirinkite laiką",
    "Color" : "Spalva",
    "Image" : "Paveikslas",
    "Document" : "Dokumentas",
    "Presentation" : "Pateiktis",
    "Spreadsheet" : "Skaičiuoklė",
    "Text" : "Tekstas",
    "Phone number" : "Telefono numeris",
    "Email address" : "El. pašto adresas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> forms-v5.2.3.tar.gz: forms/l10n/lt_LT.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Anketos",
    "{user} has shared the form {formTitle} with you" : "{user} pradėjo bendrinti su jumis anketą, pavadinimu {formTitle}",
    "Anonymous user" : "Anoniminis naudotojas",
    "A form has been <strong>shared</strong> with you" : "Su jumis pradėta <strong>bendrinti</strong> anketa",
    "Someone <strong>answered</strong> a form" : "Kažkas <strong>užpildė</strong> anketą",
    "No" : "Ne",
    "Yes" : "Taip",
    "Question" : "Klausimas",
    "Answer" : "Atsakymas",
    "Copy" : "Kopija",
    "Anonymous response" : "Anoniminis atsakymas",
    "Shared by %s" : "Bendrina %s",
    "responses" : "atsakymai",
    "User ID" : "Naudotojo ID",
    "Timestamp" : "Laiko žyma",
    "An error occurred while loading the forms list" : "Įkeliant anketų sąrašą, įvyko klaida",
    "Form not found" : "Anketa nerasta",
    "Unable to create a new form" : "Nepavyko sukurti naujos anketos",
    "Unable to copy form" : "Nepavyko nukopijuoti anketos",
    "New form" : "Nauja anketa",
    "Your forms" : "Jūsų anketos",
    "Shared with you" : "Bendrinama su jumis",
    "Archived forms" : "Archyvuotos anketos",
    "No forms created yet" : "Kol kas nėra sukurtų anketų",
    "Create a form" : "Sukurti anketą",
    "Select a form or create a new one" : "Pasirinkite anketą arba sukurkite naują",
    "Please select a form" : "Pasirinkite anketą",
    "Create new form" : "Sukurti naują anketą",
    "This form does not exist" : "Šios anketos nėra",
    "Form expired" : "Anketa nebegalioja",
    "This form has expired and is no longer taking answers" : "Ši anketa nebegalioja ir daugiau nebepriima atsakymų",
    "Error while saving configuration" : "Klaida įrašant konfigūraciją",
    "Error while reloading config" : "Klaida iš naujo įkeliant konfigūraciją",
    "Form creation" : "Anketos kūrimas",
    "Select groups" : "Pasirinkti grupes",
    "Form sharing" : "Anketos bendrinimas",
    "Allow sharing by link" : "Leisti bendrinti pagal nuorodą",
    "Delete form" : "Ištrinti anketą",
    "Expired {relativeDate}" : "Nustojo galioti {relativeDate}",
    "Expires {relativeDate}" : "Galioja iki {relativeDate}",
    "Error while deleting {title}" : "Klaida ištrinant {title}",
    "Edit form" : "Taisyti anketą",
    "Share form" : "Bendrinti anketą",
    "Results" : "Rezultatai",
    "Copy form" : "Kopijuoti anketą",
    "Unarchive form" : "Išarchyvuoti anketą",
    "Archive form" : "Archyvuoti anketą",
    "Are you sure you want to delete {title}?" : "Ar tikrai norite ištrinti {title}?",
    "Cancel" : "Atsisakyti",
    "Options" : "Parinktys",
    "Answer number {index}" : "Atsakymas nr. {index}",
    "Error while saving the answer" : "Klaida įrašant atsakymą",
    "Delete answer" : "Ištrinti atsakymą",
    "This question needs a title!" : "Šiam klausimui reikalinga antraštė!",
    "Question number {index}" : "Klausimas nr. {index}",
    "Move question up" : "Pakelti klausimą",
    "Move question down" : "Nuleisti klausimą",
    "Title of question number {index}" : "Klausimo nr. {index} antraštė",
    "Required" : "Privalomas",
    "Technical name of the question" : "Techninis klausimo pavadinimas",
    "Technical name" : "Techninis pavadinimas",
    "Copy question" : "Kopijuoti klausimą",
    "Delete question" : "Ištrinti klausimą",
    "Allowed file types: {fileTypes}." : "Leidžiami failo tipai: {fileTypes}.",
    "All file types are allowed." : "Leidžiami visi failo tipai.",
    "Maximum file size" : "Didžiausias failo dydis",
    "Delete" : "Ištrinti",
    "Add new file as answer" : "Pridėti naują failą kaip atsakymą",
    "A long answer for the question “{text}”" : "Ilgas atsakymas į klausimą „{text}“",
    "Other" : "Kita",
    "A short answer for the question “{text}”" : "Trumpas atsakymas į klausimą „{text}“",
    "No response" : "Nėra atsakymo",
    "Delete this response" : "Ištrinti šį atsakymą",
    "Expired on {date}" : "Nustojo galioti {date}",
    "Expires on {date}" : "Galioja iki {date}",
    "never" : "niekada",
    "Allow multiple responses per person" : "Leisti kiekvienam žmogui atsakinėti po keletą kartų",
    "Set expiration date" : "Nustatyti galiojimo pabaigos datą",
    "Group" : "Grupė",
    "Team" : "Komanda",
    "Permissions" : "Leidimai",
    "There was an error while adding the share" : "Pridedant viešinį įvyko klaida",
    "There was an error while adding the link" : "Pridedant nuorodą įvyko klaida",
    "There was an error while removing the share" : "Šalinant viešinį įvyko klaida",
    "Share link" : "Viešinio nuoroda",
    "Add link" : "Pridėti nuorodą",
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Show QR code" : "Rodyti QR kodą",
    "Copy embedding code" : "Kopijuoti įterpimo kodą",
    "Remove link" : "Šalinti nuorodą",
    "Internal link" : "Vidinė nuoroda",
    "Show to all accounts on sidebar" : "Rodyti visoms paskyroms šoninėje juostoje",
    "Search for a user" : "Ieškoti naudotojo",
    "View form" : "Rodyti anketą",
    "View" : "Rodyti",
    "Edit" : "Taisyti",
    "Show results" : "Rodyti rezultatus",
    "Share" : "Bendrinti",
    "Responses are anonymous." : "Atsakymai yra anoniminiai.",
    "An asterisk (*) indicates mandatory questions." : "Privalomi klausimai yra pažymėti žvaigždute (*).",
    "Expired {relativeDate}." : "Nustojo galioti {relativeDate}.",
    "Expires {relativeDate}." : "Galioja iki {relativeDate}.",
    "There was an error while adding the new question" : "Pridedant naują klausimą, įvyko klaida",
    "There was an error while removing the question" : "Šalinant klausimą, įvyko klaida",
    "Error while saving form" : "Klaida įrašant anketą",
    "Create form" : "Sukurti anketą",
    "Form is archived" : "Anketa yra archyvuota",
    "Form title" : "Anketos pavadinimas",
    "Description" : "Aprašas",
    "Add a question" : "Pridėti klausimą",
    "Summary" : "Santrauka",
    "Responses" : "Atsakymai",
    "There was an error while loading the results" : "Įkeliant rezultatus, įvyko klaida",
    "Export successful to {file}" : "Eksportavimas į {file} sėkmingas",
    "There was an error while removing this response" : "Šalinant šį atsakymą, įvyko klaida",
    "There was an error while removing responses" : "Šalinant atsakymus, įvyko klaida",
    "Create XLSX" : "Sukurti XLSX",
    "Create CSV" : "Sukurti CSV",
    "Create ODS" : "Sukurti ODS",
    "{amount} responses" : "Atsakymų: {amount}",
    "Download" : "Atsisiųsti",
    "Delete all responses" : "Ištrinti visus atsakymus",
    "Search" : "Paieška",
    "No results found" : "Nerasta jokių rezultatų",
    "No responses yet" : "Kol kas atsakymų nėra",
    "Results of submitted forms will show up here" : "Čia bus rodomi pateiktų anketų rezultatai",
    "Form settings" : "Anketos nustatymai",
    "Sharing" : "Bendrinimas",
    "Settings" : "Nustatymai",
    "Abort" : "Nutraukti",
    "Submit" : "Pateikti",
    "Clear" : "Išvalyti",
    "There was an error submitting the form" : "Pateikiant anketą, įvyko klaida",
    "Submit form" : "Pateikti anketą",
    "Thank you for completing the form!" : "Dėkojame, kad užpildėte anketą!",
    "Error while saving question" : "Klaida įrašant klausimą",
    "Form link copied" : "Anketos nuoroda nukopijuota",
    "Cannot copy, please copy the link manually" : "Nepavyksta nukopijuoti, nukopijuokite nuorodą rankiniu būdu",
    "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
    "No elements found." : "Nerasta jokių elementų.",
    "Checkboxes" : "Žymimieji langeliai",
    "Checkbox question title" : "Žymimųjų langelių klausimo antraštė",
    "Enter your answer" : "Įveskite atsakymą",
    "This question needs a title and at least one answer!" : "Šiam klausimui reikia antraštės ir bent vieno atsakymo!",
    "Dropdown" : "Išskleidžiamasis langelis",
    "Dropdown question title" : "Išskleidžiamojo langelio klausimo antraštė",
    "People can pick one option" : "Žmonės galės pasirinkti vieną variantą",
    "Pick an option" : "Pasirinkite variantą",
    "File" : "Failas",
    "Short answer" : "Trumpas atsakymas",
    "Short answer question title" : "Trumpo atsakymo klausimo antraštė",
    "People can enter a short answer" : "Žmonės galės įvesti trumpą atsakymą",
    "Long text" : "Ilgas atsakymas",
    "Long text question title" : "Ilgo teksto klausimo antraštė",
    "People can enter a long text" : "Žmonės galės įvesti ilgą atsakymą",
    "Date" : "Data",
    "Date question title" : "Datos klausimo antraštė",
    "People can pick a date" : "Žmonės galės pasirinkti datą",
    "Pick a date" : "Pasirinkite datą",
    "Datetime" : "Data ir laikas",
    "Datetime question title" : "Datos ir laiko klausimo antraštė",
    "People can pick a date and time" : "Žmonės galės pasirinkti datą ir laiką",
    "Pick a date and time" : "Pasirinkite datą ir laiką",
    "Time" : "Laikas",
    "Pick a time" : "Pasirinkite laiką",
    "Color" : "Spalva",
    "Image" : "Paveikslas",
    "Document" : "Dokumentas",
    "Presentation" : "Pateiktis",
    "Spreadsheet" : "Skaičiuoklė",
    "Text" : "Tekstas",
    "Phone number" : "Telefono numeris",
    "Email address" : "El. pašto adresas",
    "Loading forms …" : "Įkeliamos anketos…",
    "Uploading …" : "Įkeliama…",
    "Search for user, group or team …" : "Ieškoti naudotojo, grupės ar komandos…",
    "Loading {title} …" : "Įkeliama {title}…",
    "Loading responses …" : "Įkeliami atsakymai…",
    "Submitting form …" : "Anketa pateikiama…"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
